@@ -1,10 +1,7 @@
 """SatNOGS Network API serializers, django rest framework"""
 #  pylint: disable=no-self-use
-from __future__ import absolute_import, division
-
 from collections import defaultdict
 
-from future.builtins import round
 from rest_framework import serializers
 
 from network.base.db_api import DBConnectionError, get_transmitters_by_uuid_set
@@ -35,16 +32,22 @@ class ObservationSerializer(serializers.ModelSerializer):
     station_lat = serializers.SerializerMethodField()
     station_lng = serializers.SerializerMethodField()
     station_alt = serializers.SerializerMethodField()
-    demoddata = DemodDataSerializer(many=True)
+    status = serializers.SerializerMethodField()
+    waterfall_status = serializers.SerializerMethodField()
+    vetted_status = serializers.SerializerMethodField()  # Deprecated
+    vetted_user = serializers.SerializerMethodField()  # Deprecated
+    vetted_datetime = serializers.SerializerMethodField()  # Deprecated
+    demoddata = DemodDataSerializer(required=False, many=True)
 
     class Meta:
         model = Observation
         fields = (
             'id', 'start', 'end', 'ground_station', 'transmitter', 'norad_cat_id', 'payload',
             'waterfall', 'demoddata', 'station_name', 'station_lat', 'station_lng', 'station_alt',
-            'vetted_status', 'archived', 'archive_url', 'client_version', 'client_metadata',
-            'vetted_user', 'vetted_datetime', 'rise_azimuth', 'set_azimuth', 'max_altitude',
-            'transmitter_uuid', 'transmitter_description', 'transmitter_type',
+            'vetted_status', 'vetted_user', 'vetted_datetime', 'archived', 'archive_url',
+            'client_version', 'client_metadata', 'status', 'waterfall_status',
+            'waterfall_status_user', 'waterfall_status_datetime', 'rise_azimuth', 'set_azimuth',
+            'max_altitude', 'transmitter_uuid', 'transmitter_description', 'transmitter_type',
             'transmitter_uplink_low', 'transmitter_uplink_high', 'transmitter_uplink_drift',
             'transmitter_downlink_low', 'transmitter_downlink_high', 'transmitter_downlink_drift',
             'transmitter_mode', 'transmitter_invert', 'transmitter_baud', 'transmitter_updated',
@@ -52,18 +55,18 @@ class ObservationSerializer(serializers.ModelSerializer):
         )
         read_only_fields = [
             'id', 'start', 'end', 'observation', 'ground_station', 'transmitter', 'norad_cat_id',
-            'archived', 'archive_url', 'station_name', 'station_lat', 'station_lng', 'vetted_user',
-            'station_alt', 'vetted_status', 'vetted_datetime', 'rise_azimuth', 'set_azimuth',
-            'max_altitude', 'transmitter_uuid', 'transmitter_description', 'transmitter_type',
-            'transmitter_uplink_low', 'transmitter_uplink_high', 'transmitter_uplink_drift',
-            'transmitter_downlink_low', 'transmitter_downlink_high', 'transmitter_downlink_drift',
-            'transmitter_mode', 'transmitter_invert', 'transmitter_baud', 'transmitter_created',
-            'transmitter_updated', 'tle'
+            'archived', 'archive_url', 'station_name', 'station_lat', 'station_lng',
+            'waterfall_status_user', 'status', 'waterfall_status', 'station_alt', 'vetted_status',
+            'vetted_user', 'vetted_datetime', 'waterfall_status_datetime', 'rise_azimuth',
+            'set_azimuth', 'max_altitude', 'transmitter_uuid', 'transmitter_description',
+            'transmitter_type', 'transmitter_uplink_low', 'transmitter_uplink_high',
+            'transmitter_uplink_drift', 'transmitter_downlink_low', 'transmitter_downlink_high',
+            'transmitter_downlink_drift', 'transmitter_mode', 'transmitter_invert',
+            'transmitter_baud', 'transmitter_created', 'transmitter_updated', 'tle'
         ]
 
     def update(self, instance, validated_data):
         """Updates observation object with validated data"""
-        validated_data.pop('demoddata')
         super(ObservationSerializer, self).update(instance, validated_data)
         return instance
 
@@ -113,6 +116,30 @@ class ObservationSerializer(serializers.ModelSerializer):
         except AttributeError:
             return None
 
+    def get_status(self, obj):
+        """Returns Observation status"""
+        return obj.status_label
+
+    def get_waterfall_status(self, obj):
+        """Returns Observation status"""
+        return obj.waterfall_status_label
+
+    def get_vetted_status(self, obj):
+        """DEPRECATED: Returns vetted status"""
+        if obj.status_label == 'future':
+            return 'unknown'
+        return obj.status_label
+
+    def get_vetted_user(self, obj):
+        """DEPRECATED: Returns vetted user"""
+        if obj.waterfall_status_user:
+            return obj.waterfall_status_user.pk
+        return None
+
+    def get_vetted_datetime(self, obj):
+        """DEPRECATED: Returns vetted datetime"""
+        return obj.waterfall_status_datetime
+
 
 class NewObservationListSerializer(serializers.ListSerializer):
     """SatNOGS Network New Observation API List Serializer"""
