@@ -1,6 +1,4 @@
 """SatNOGS Network API django rest framework Views"""
-from __future__ import absolute_import
-
 from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import Count
 from django.shortcuts import get_object_or_404
@@ -12,6 +10,7 @@ from rest_framework.serializers import ValidationError
 from network.api import filters, pagination, serializers
 from network.api.perms import StationOwnerPermission
 from network.base.models import LatestTle, Observation, Station, Transmitter
+from network.base.rating_tasks import rate_observation
 from network.base.tasks import sync_to_db
 from network.base.validators import NegativeElevationError, \
     ObservationOverlapError, SinglePassError
@@ -22,7 +21,7 @@ class ObservationView(  # pylint: disable=R0901
         mixins.CreateModelMixin, viewsets.GenericViewSet):
     """SatNOGS Network Observation API view class"""
     queryset = Observation.objects.prefetch_related('satellite', 'demoddata', 'ground_station')
-    filter_class = filters.ObservationViewFilter
+    filterset_class = filters.ObservationViewFilter
     permission_classes = [StationOwnerPermission]
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
@@ -84,6 +83,10 @@ class ObservationView(  # pylint: disable=R0901
         # False-positive no-member (E1101) pylint error:
         # Parent class rest_framework.mixins.UpdateModelMixin provides the 'update' method
         super(ObservationView, self).update(request, *args, **kwargs)  # pylint: disable=E1101
+        if request.data.get('waterfall'):
+            rate_observation.delay(instance.id, 'waterfall_upload')
+        if request.data.get('demoddata'):
+            rate_observation.delay(instance.id, 'data_upload')
         return Response(status=status.HTTP_200_OK)
 
 
@@ -94,7 +97,7 @@ class StationView(  # pylint: disable=R0901
         total_obs=Count('observations'),
     ).prefetch_related('antennas', 'antennas__antenna_type', 'antennas__frequency_ranges')
     serializer_class = serializers.StationSerializer
-    filter_class = filters.StationViewFilter
+    filterset_class = filters.StationViewFilter
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
 
@@ -103,7 +106,7 @@ class TransmitterView(  # pylint: disable=R0901
     """SatNOGS Network Transmitter API view class"""
     queryset = Transmitter.objects.all().order_by('uuid')
     serializer_class = serializers.TransmitterSerializer
-    filter_class = filters.TransmitterViewFilter
+    filterset_class = filters.TransmitterViewFilter
     pagination_class = pagination.LinkedHeaderPageNumberPagination
 
 
@@ -111,14 +114,14 @@ class JobView(viewsets.ReadOnlyModelViewSet):  # pylint: disable=R0901
     """SatNOGS Network Job API view class"""
     queryset = Observation.objects.filter(payload='')
     serializer_class = serializers.JobSerializer
-    filter_class = filters.ObservationViewFilter
-    filter_fields = ('ground_station')
+    filterset_class = filters.ObservationViewFilter
+    filterset_fields = ('ground_station')
 
     def get_queryset(self):
         """Returns queryset for Job API view"""
         queryset = self.queryset.filter(start__gte=now()).prefetch_related('tle')
         ground_station_id = self.request.query_params.get('ground_station', None)
-        if ground_station_id and self.request.user.is_authenticated():
+        if ground_station_id and self.request.user.is_authenticated:
             ground_station = get_object_or_404(Station, id=ground_station_id)
             if ground_station.owner == self.request.user:
                 lat = self.request.query_params.get('lat', None)
