@@ -1,6 +1,4 @@
 """Django database base model for SatNOGS Network"""
-from __future__ import absolute_import, division
-
 import codecs
 import logging
 import os
@@ -16,7 +14,6 @@ from django.db import models
 from django.db.models import OuterRef, Subquery
 from django.dispatch import receiver
 from django.urls import reverse
-from django.utils.encoding import python_2_unicode_compatible
 from django.utils.html import format_html
 from django.utils.timezone import now
 from PIL import Image
@@ -69,7 +66,6 @@ def validate_image(fieldfile_obj):
         raise ValidationError("Max file size is %sMB" % str(megabyte_limit))
 
 
-@python_2_unicode_compatible
 class Station(models.Model):
     """Model for SatNOGS ground stations."""
     owner = models.ForeignKey(
@@ -147,12 +143,12 @@ class Station(models.Model):
         """Return the success rate of the station - successful observation over failed ones"""
         rate = cache.get('station-{0}-rate'.format(self.id))
         if not rate:
-            observations = self.observations.exclude(testing=True).exclude(vetted_status="unknown")
+            observations = self.observations.exclude(testing=True).exclude(status__range=(0, 99))
             success = observations.filter(
-                id__in=(o.id for o in observations if o.is_good or o.is_bad)
+                id__in=(o.id for o in observations if o.status >= 100 or -100 <= o.status < 0)
             ).count()
             if observations:
-                rate = int(100 * (float(success) / float(observations.count())))
+                rate = int(100 * (success / observations.count()))
                 cache.set('station-{0}-rate'.format(self.id), rate)
             else:
                 rate = False
@@ -193,7 +189,6 @@ class Station(models.Model):
             )
 
 
-@python_2_unicode_compatible
 class AntennaType(models.Model):
     """Model for antenna types."""
     name = models.CharField(max_length=25, unique=True)
@@ -202,7 +197,6 @@ class AntennaType(models.Model):
         return self.name
 
 
-@python_2_unicode_compatible
 class Antenna(models.Model):
     """Model for antennas of SatNOGS ground stations."""
     antenna_type = models.ForeignKey(
@@ -229,7 +223,6 @@ class Antenna(models.Model):
         return "%s" % (self.antenna_type.name)
 
 
-@python_2_unicode_compatible
 class FrequencyRange(models.Model):
     """Model for frequency ranges of antennas."""
     antenna = models.ForeignKey(Antenna, on_delete=models.CASCADE, related_name='frequency_ranges')
@@ -279,7 +272,6 @@ class FrequencyRange(models.Model):
             )
 
 
-@python_2_unicode_compatible
 class StationStatusLog(models.Model):
     """Model for keeping Status log for Station."""
     station = models.ForeignKey(
@@ -296,7 +288,6 @@ class StationStatusLog(models.Model):
         return '{0} - {1}'.format(self.station, self.status)
 
 
-@python_2_unicode_compatible
 class Satellite(models.Model):
     """Model for SatNOGS satellites."""
     norad_cat_id = models.PositiveIntegerField(db_index=True)
@@ -322,7 +313,6 @@ class Satellite(models.Model):
         return self.name
 
 
-@python_2_unicode_compatible
 class Tle(models.Model):
     """Model for TLEs."""
     tle0 = models.CharField(max_length=100, blank=True, db_index=True)
@@ -359,7 +349,6 @@ class LatestTleManager(models.Manager):  # pylint: disable=R0903
                      self).get_queryset().filter(updated=Subquery(subquery.values('updated')[:1]))
 
 
-@python_2_unicode_compatible
 class LatestTle(Tle):
     """LatestTle is the latest entry of a Satellite Tle objects
     """
@@ -372,7 +361,6 @@ class LatestTle(Tle):
         return '{:d} - {:s}'.format(self.id, self.tle0)
 
 
-@python_2_unicode_compatible
 class Transmitter(models.Model):
     """Model for antennas transponders."""
     uuid = ShortUUIDField(db_index=True)
@@ -382,7 +370,6 @@ class Transmitter(models.Model):
         return self.uuid
 
 
-@python_2_unicode_compatible
 class Observation(models.Model):
     """Model for SatNOGS observations."""
     satellite = models.ForeignKey(
@@ -403,13 +390,28 @@ class Observation(models.Model):
     client_metadata = models.TextField(blank=True)
     payload = models.FileField(upload_to=_name_obs_files, blank=True, null=True)
     waterfall = models.ImageField(upload_to=_name_obs_files, blank=True, null=True)
-    vetted_datetime = models.DateTimeField(null=True, blank=True)
-    vetted_user = models.ForeignKey(
-        User, related_name='observations_vetted', on_delete=models.SET_NULL, null=True, blank=True
+    """
+    Meaning of values:
+    True -> Waterfall has signal of the observed satellite (with-signal)
+    False -> Waterfall has not signal of the observed satellite (without-signal)
+    None -> Uknown whether waterfall has or hasn't signal of the observed satellite (unknown)
+    """
+    waterfall_status = models.BooleanField(blank=True, null=True, default=None)
+    waterfall_status_datetime = models.DateTimeField(null=True, blank=True)
+    waterfall_status_user = models.ForeignKey(
+        User, related_name='waterfalls_vetted', on_delete=models.SET_NULL, null=True, blank=True
     )
     vetted_status = models.CharField(
         choices=OBSERVATION_STATUSES, max_length=20, default='unknown'
     )
+    """
+    Meaning of values:
+    x < -100      -> Failed
+    -100 =< x < 0 -> Bad
+    0 =< x < 100  -> Unknown (Future if observation not completed)
+    100 =< x      -> Good
+    """
+    status = models.SmallIntegerField(default=0)
     testing = models.BooleanField(default=False)
     rise_azimuth = models.FloatField(blank=True, null=True)
     max_altitude = models.FloatField(blank=True, null=True)
@@ -452,29 +454,53 @@ class Observation(models.Model):
         """Return true if observation has started (start time is in the past)"""
         return self.start < now()
 
-    # this payload has been vetted good/bad/failed by someone
+    # The values bellow are used as returned values in the API and for css rules in templates
     @property
-    def is_vetted(self):
-        """Return true if observation is vetted"""
-        return not self.vetted_status == 'unknown'
+    def status_label(self):
+        """Return label for status field"""
+        if self.is_future:
+            return "future"
+        if self.status < -100:
+            return "failed"
+        if -100 <= self.status < 0:
+            return "bad"
+        if 0 <= self.status < 100:
+            return "unknown"
+        return "good"
 
-    # this payload has been vetted as good by someone
+    # The values bellow are used as displayed values in templates
     @property
-    def is_good(self):
-        """Return true if observation is vetted as good"""
-        return self.vetted_status == 'good'
+    def status_display(self):
+        """Return display name for status field"""
+        if self.is_future:
+            return "Future"
+        if self.status < -100:
+            return "Failed"
+        if -100 <= self.status < 0:
+            return "Bad"
+        if 0 <= self.status < 100:
+            return "Unknown"
+        return "Good"
 
-    # this payload has been vetted as bad by someone
+    # The values bellow are used as returned values in the API and for css rules in templates
     @property
-    def is_bad(self):
-        """Return true if observation is vetted as bad"""
-        return self.vetted_status == 'bad'
+    def waterfall_status_label(self):
+        """Return label for waterfall_status field"""
+        if self.waterfall_status is None:
+            return 'unknown'
+        if self.waterfall_status:
+            return 'with-signal'
+        return 'without-signal'
 
-    # this payload has been vetted as failed by someone
+    # The values bellow are used as displayed values in templates
     @property
-    def is_failed(self):
-        """Return true if observation is vetted as failed"""
-        return self.vetted_status == 'failed'
+    def waterfall_status_display(self):
+        """Return display name for waterfall_status field"""
+        if self.waterfall_status is None:
+            return 'Unknown'
+        if self.waterfall_status:
+            return 'With Signal'
+        return 'Without Signal'
 
     @property
     def has_waterfall(self):
@@ -551,7 +577,6 @@ def observation_remove_files(sender, instance, **kwargs):  # pylint: disable=W06
             os.remove(instance.waterfall.path)
 
 
-@python_2_unicode_compatible
 class DemodData(models.Model):
     """Model for DemodData."""
     observation = models.ForeignKey(
