@@ -2,15 +2,12 @@
 # ephem is missing lon, lat, elevation and horizon attributes in Observer class slots,
 # Disable assigning-non-slot pylint error:
 # pylint: disable=E0237
-from __future__ import absolute_import, division
-
 import math
 from datetime import timedelta
 
 import ephem
 from django.conf import settings
 from django.utils.timezone import make_aware, now, utc
-from past.utils import old_div
 
 from network.base.models import LatestTle, Observation, Satellite
 from network.base.perms import schedule_stations_perms
@@ -150,7 +147,7 @@ def create_station_windows(scheduled_obs, overlapped, pass_params, observer, sat
                     create_station_window(
                         window_start, window_end, get_azimuth(observer, satellite, window_start),
                         get_azimuth(observer, satellite, window_end), altitude, tle, True, True,
-                        min(1, 1 - (float(window_duration) / float(initial_duration)))
+                        min(1, 1 - (window_duration / initial_duration))
                     )
                 )
         elif overlapped == 2:
@@ -168,7 +165,7 @@ def create_station_windows(scheduled_obs, overlapped, pass_params, observer, sat
                 create_station_window(
                     pass_params['rise_time'], pass_params['set_time'], pass_params['rise_az'],
                     pass_params['set_az'], pass_params['tca_alt'], tle, duration_validity, True,
-                    min(1, 1 - (float(window_duration) / float(initial_duration)))
+                    min(1, 1 - (window_duration / initial_duration))
                 )
             )
     else:
@@ -252,7 +249,9 @@ def predict_available_observation_windows(station, min_horizon, overlapped, tle,
     while True:
         try:
             pass_params = next_pass(observer, satellite)
-        except ValueError:
+        # We catch TypeError, to avoid cases like this one that is described in ephem issue:
+        # https://github.com/brandon-rhodes/pyephem/issues/176
+        except (TypeError, ValueError):
             break
 
         # no match if the sat will not rise above the configured min horizon
@@ -317,9 +316,7 @@ def create_new_observation(station, transmitter, start, end, author):
     observer.lat = str(station.lat)
     observer.elevation = station.alt
 
-    # Replace with the following after Python 3 migration:
-    # mid_pass_time = start + (end - start) / 2
-    mid_pass_time = start + old_div((end - start), 2)
+    mid_pass_time = start + (end - start) / 2
 
     rise_azimuth = get_azimuth(observer, sat_ephem, start)
     rise_altitude = get_altitude(observer, sat_ephem, start)
