@@ -1,6 +1,4 @@
 """Django database base model for SatNOGS Network"""
-from __future__ import absolute_import, division
-
 import os
 import struct
 from datetime import timedelta
@@ -11,6 +9,7 @@ from django.utils.timezone import now
 from tinytag import TinyTag, TinyTagException
 
 from network.base.models import Observation, Station, StationStatusLog, Tle
+from network.base.rating_tasks import rate_observation
 from network.base.tasks import archive_audio, delay_task_with_lock
 
 
@@ -19,7 +18,6 @@ def _observation_post_save(sender, instance, created, **kwargs):  # pylint: disa
     Post save Observation operations
     * Check audio file for duration less than 1 sec
     * Validate audio file
-    * Auto vet as good observation with DemodData
     * Mark Observations from testing stations
     * Run task for archiving audio
     """
@@ -34,6 +32,7 @@ def _observation_post_save(sender, instance, created, **kwargs):  # pylint: disa
                 delay_task_with_lock(
                     archive_audio, instance.id, settings.ARCHIVE_AUDIO_LOCK_EXPIRATION, instance.id
                 )
+                rate_observation(instance.id, 'audio_upload', audio_metadata.duration)
         except TinyTagException:
             # Remove invalid audio file
             instance.payload.delete()
