@@ -1,6 +1,4 @@
 """SatNOGS Network Celery task functions"""
-from __future__ import absolute_import, division, print_function
-
 import json
 import os
 from datetime import timedelta
@@ -110,6 +108,11 @@ def fetch_data():
     for satellite in r_satellites.json():
         norad_cat_id = satellite['norad_cat_id']
         satellite.pop('decayed', None)
+        satellite.pop('launched', None)
+        satellite.pop('deployed', None)
+        satellite.pop('website', None)
+        satellite.pop('operator', None)
+        satellite.pop('countries', None)
         try:
             # Update Satellite
             existing_satellite = Satellite.objects.get(norad_cat_id=norad_cat_id)
@@ -198,7 +201,7 @@ def clean_observations():
                                       .exclude(payload='')
     for obs in observations:
         if settings.ENVIRONMENT == 'stage':
-            if not obs.is_good:
+            if not obs.status >= 100:
                 obs.delete()
                 continue
         if os.path.isfile(obs.payload.path):
@@ -276,10 +279,10 @@ def stations_cache_rates():
     """Cache the success rate of the stations"""
     stations = Station.objects.all()
     for station in stations:
-        observations = station.observations.exclude(testing=True).exclude(vetted_status="unknown")
+        observations = station.observations.exclude(testing=True).exclude(status__range=(0, 99))
         success = observations.filter(
-            id__in=(o.id for o in observations if o.is_good or o.is_bad)
+            id__in=(o.id for o in observations if o.status >= 100 or -100 <= o.status < 0)
         ).count()
         if observations:
-            rate = int(100 * (float(success) / float(observations.count())))
+            rate = int(100 * (success / observations.count()))
             cache.set('station-{0}-rate'.format(station.id), rate, 60 * 60 * 2)
