@@ -1,12 +1,10 @@
 """Django base views for SatNOGS Network"""
-from __future__ import absolute_import
-
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
-from django.core.urlresolvers import reverse
 from django.http import JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
+from django.urls import reverse
 from django.utils.timezone import now
 from django.views.generic import ListView
 
@@ -14,6 +12,7 @@ from network.base.db_api import DBConnectionError, get_transmitters_by_norad_id
 from network.base.decorators import ajax_required
 from network.base.models import Observation, Satellite, Station
 from network.base.perms import delete_perms, schedule_perms, vet_perms
+from network.base.rating_tasks import rate_observation
 from network.base.stats import satellite_stats_by_transmitter_list, \
     transmitters_with_stats
 from network.base.utils import community_get_discussion_details
@@ -29,7 +28,7 @@ class ObservationListView(ListView):  # pylint: disable=R0901
     paginate_by = settings.ITEMS_PER_PAGE
     template_name = 'base/observations.html'
     str_filters = ['norad', 'observer', 'station', 'start', 'end']
-    flag_filters = ['bad', 'good', 'unvetted', 'future', 'failed']
+    flag_filters = ['bad', 'good', 'unknown', 'future', 'failed']
     filtered = None
 
     def get_filter_params(self):
@@ -54,11 +53,12 @@ class ObservationListView(ListView):  # pylint: disable=R0901
     def get_queryset(self):
         """
         Optionally filter based on norad get argument
-        Optionally filter based on future/good/bad/unvetted/failed
+        Optionally filter based on future/good/bad/unknown/failed
         """
         filter_params = self.get_filter_params()
 
         results = self.request.GET.getlist('results')
+        rated = self.request.GET.getlist('rated')
 
         observations = Observation.objects.prefetch_related(
             'satellite', 'demoddata', 'author', 'ground_station'
@@ -85,39 +85,50 @@ class ObservationListView(ListView):  # pylint: disable=R0901
             (
                 not all(
                     [
-                        filter_params['bad'], filter_params['good'], filter_params['unvetted'],
+                        filter_params['bad'], filter_params['good'], filter_params['unknown'],
                         filter_params['future'], filter_params['failed']
                     ]
                 )
-            ) or results or filter_dict
+            ) or results or rated or filter_dict
         )
 
         observations = observations.filter(**filter_dict)
 
-        for filter_name in ['bad', 'good', 'failed']:
-            if not filter_params[filter_name]:
-                observations = observations.exclude(vetted_status=filter_name)
-
-        if not filter_params['unvetted']:
-            observations = observations.exclude(vetted_status='unknown', end__lte=now())
+        if not filter_params['failed']:
+            observations = observations.exclude(status__lt=-100)
+        if not filter_params['bad']:
+            observations = observations.exclude(status__range=(-100, -1))
+        if not filter_params['unknown']:
+            observations = observations.exclude(status__range=(0, 99), end__lte=now())
         if not filter_params['future']:
-            observations = observations.exclude(vetted_status='unknown', end__gt=now())
+            observations = observations.exclude(end__gt=now())
+        if not filter_params['good']:
+            observations = observations.exclude(status__gte=100)
+
         if results:
             if 'w0' in results:
                 observations = observations.filter(waterfall='')
             elif 'w1' in results:
                 observations = observations.exclude(waterfall='')
             if 'a0' in results:
-                observations = observations.exclude(archived=True).filter(payload='')
+                observations = observations.filter(archived=False, payload='')
             elif 'a1' in results:
                 observations = observations.exclude(archived=False, payload='')
             if 'd0' in results:
                 observations = observations.filter(demoddata__payload_demod__isnull=True)
             elif 'd1' in results:
                 observations = observations.exclude(demoddata__payload_demod__isnull=True)
+
+        if rated:
+            if 'rwu' in rated:
+                observations = observations.filter(waterfall_status__isnull=True)
+            elif 'rw1' in rated:
+                observations = observations.filter(waterfall_status=True)
+            elif 'rw0' in rated:
+                observations = observations.filter(waterfall_status=False)
         return observations
 
-    def get_context_data(self, **kwargs):
+    def get_context_data(self, **kwargs):  # pylint: disable=W0221
         """
         Need to add a list of satellites to the context for the template
         """
@@ -135,10 +146,11 @@ class ObservationListView(ListView):  # pylint: disable=R0901
         context['future'] = self.request.GET.get('future', '1')
         context['bad'] = self.request.GET.get('bad', '1')
         context['good'] = self.request.GET.get('good', '1')
-        context['unvetted'] = self.request.GET.get('unvetted', '1')
+        context['unknown'] = self.request.GET.get('unknown', '1')
         context['failed'] = self.request.GET.get('failed', '1')
         context['results'] = self.request.GET.getlist('results')
-        context['filtered'] = self.filtered
+        context['rated'] = self.request.GET.getlist('rated')
+        context['filtered'] = bool(self.filtered)
         if norad_cat_id is not None and norad_cat_id != '':
             context['norad'] = int(norad_cat_id)
         if observer is not None and observer != '':
@@ -214,8 +226,8 @@ def observation_delete(request, observation_id):
 
 @login_required
 @ajax_required
-def observation_vet(request, observation_id):
-    """Handles request for vetting an observation"""
+def waterfall_vet(request, observation_id):
+    """Handles request for vetting a waterfall"""
     try:
         observation = Observation.objects.get(id=observation_id)
     except Observation.DoesNotExist:
@@ -225,24 +237,51 @@ def observation_vet(request, observation_id):
     status = request.POST.get('status', None)
     can_vet = vet_perms(request.user, observation)
 
-    if status not in ['good', 'bad', 'failed', 'unknown']:
-        data = {
-            'error': 'Invalid status, select one of \'good\', \'bad\', \'failed\' and \'unknown\'.'
-        }
-        return JsonResponse(data, safe=False)
     if not can_vet:
         data = {'error': 'Permission denied.'}
         return JsonResponse(data, safe=False)
+    if not observation.has_waterfall:
+        data = {'error': 'Observation without waterfall.'}
+        return JsonResponse(data, safe=False)
 
-    observation.vetted_status = status
-    observation.vetted_user = request.user
-    observation.vetted_datetime = now()
-    observation.save(update_fields=['vetted_status', 'vetted_user', 'vetted_datetime'])
+    if status not in ['with-signal', 'without-signal', 'unknown']:
+        data = {
+            'error':
+            'Invalid status, select one of \'with-signal\', \'without-signal\' and \'unknown\'.'
+        }
+        return JsonResponse(data, safe=False)
+
+    if status == 'with-signal':
+        observation.waterfall_status = True
+    elif status == 'without-signal':
+        observation.waterfall_status = False
+    elif status == 'unknown':
+        observation.waterfall_status = None
+
+    observation.waterfall_status_user = request.user
+    observation.waterfall_status_datetime = now()
+    observation.save(
+        update_fields=['waterfall_status', 'waterfall_status_user', 'waterfall_status_datetime']
+    )
+    (observation_status, observation_status_label, observation_status_display
+     ) = rate_observation(observation.id, 'set_waterfall_status', observation.waterfall_status)
     data = {
-        'vetted_status': observation.vetted_status,
-        'vetted_status_display': observation.get_vetted_status_display(),
-        'vetted_user': observation.vetted_user.displayname,
-        'vetted_datetime': observation.vetted_datetime.strftime('%Y-%m-%d %H:%M:%S')
+        'waterfall_status_user':
+        observation.waterfall_status_user.displayname,
+        'waterfall_status_datetime':
+        observation.waterfall_status_datetime.strftime('%Y-%m-%d %H:%M:%S'),
+        'waterfall_status':
+        observation.waterfall_status,
+        'waterfall_status_label':
+        observation.waterfall_status_label,
+        'waterfall_status_display':
+        observation.waterfall_status_display,
+        'status':
+        observation_status,
+        'status_label':
+        observation_status_label,
+        'status_display':
+        observation_status_display,
     }
     return JsonResponse(data, safe=False)
 
@@ -269,7 +308,7 @@ def satellite_view(request, norad_id):
         'success_rate': satellite_stats['success_rate'],
         'good_count': satellite_stats['good_count'],
         'bad_count': satellite_stats['bad_count'],
-        'unvetted_count': satellite_stats['unvetted_count'],
+        'unknown_count': satellite_stats['unknown_count'],
         'future_count': satellite_stats['future_count'],
         'total_count': satellite_stats['total_count'],
         'transmitters': transmitters_with_stats(transmitters)
