@@ -1,6 +1,4 @@
 """Django base views for SatNOGS Network"""
-from __future__ import absolute_import
-
 from collections import defaultdict
 from datetime import datetime, timedelta
 from operator import itemgetter
@@ -9,11 +7,11 @@ import ephem
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
-from django.core.urlresolvers import reverse
 from django.db.models import Prefetch
 from django.forms import ValidationError
 from django.http import JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
+from django.urls import reverse
 from django.utils.timezone import make_aware, now, utc
 from django.views.decorators.http import require_POST
 
@@ -331,12 +329,12 @@ def pass_predictions(request, station_id):
                         'id': str(satellite.id),
                         'success_rate': str(satellite_stats['success_rate']),
                         'bad_rate': str(satellite_stats['bad_rate']),
-                        'unvetted_rate': str(satellite_stats['unvetted_rate']),
+                        'unknown_rate': str(satellite_stats['unknown_rate']),
                         'future_rate': str(satellite_stats['future_rate']),
                         'total_count': str(satellite_stats['total_count']),
                         'good_count': str(satellite_stats['good_count']),
                         'bad_count': str(satellite_stats['bad_count']),
-                        'unvetted_count': str(satellite_stats['unvetted_count']),
+                        'unknown_count': str(satellite_stats['unknown_count']),
                         'future_count': str(satellite_stats['future_count']),
                         'norad_cat_id': str(satellite.norad_cat_id),
                         'tle1': window['tle1'],
