@@ -4,8 +4,6 @@ For local installation settings please copy .env-dist to .env and edit
 the appropriate settings in that file. You should not need to edit this
 file for local settings!
 """
-from __future__ import absolute_import
-
 from decouple import Csv, config
 from dj_database_url import parse as db_url
 from sentry_sdk import init as sentry_sdk_init
@@ -171,9 +169,12 @@ SATELLITE_DEFAULT_IMAGE = 'https://db.satnogs.org/static/img/sat.png'
 COMPRESS_ENABLED = config('COMPRESS_ENABLED', default=False, cast=bool)
 COMPRESS_OFFLINE = config('COMPRESS_OFFLINE', default=False, cast=bool)
 COMPRESS_CACHE_BACKEND = config('COMPRESS_CACHE_BACKEND', default='default')
-COMPRESS_CSS_FILTERS = [
-    'compressor.filters.css_default.CssAbsoluteFilter', 'compressor.filters.cssmin.rCSSMinFilter'
-]
+COMPRESS_FILTERS = {
+    'css': [
+        'compressor.filters.css_default.CssAbsoluteFilter',
+        'compressor.filters.cssmin.rCSSMinFilter'
+    ]
+}
 COMPRESS_PRECOMPILERS = (('text/scss', 'sass --scss {infile} {outfile}'), )
 
 # App conf
@@ -318,6 +319,9 @@ CSP_STYLE_SRC = config(
 CSP_WORKER_SRC = config(
     'CSP_WORKER_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
 )
+CSP_FRAME_SRC = config(
+    'CSP_FRAME_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
+)
 CSP_CHILD_SRC = config(
     'CSP_CHILD_SRC', cast=lambda v: tuple(s.strip() for s in v.split(',')), default='blob:'
 )
